@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 # Copyright 2016 Cray Inc. All rights reserved.
 #
@@ -16,9 +14,7 @@
 #    under the License.
 
 import json
-import logging
 
-from django.conf import settings
 from django.core import urlresolvers
 from django.core.urlresolvers import reverse_lazy
 from django import template
@@ -32,9 +28,6 @@ from monitoring.overview import constants as ov_constants
 from monitoring import api
 
 
-LOG = logging.getLogger(__name__)
-
-
 STATUS = ["OK", "WARNING", "CRITICAL", "UNKNOWN"]
 
 
@@ -67,9 +60,11 @@ def show_severity(data):
     else:
         return state.upper()
 
+
 def show_alarm_id(data):
     return data['id']
 
+
 def show_metric_name(data):
     return data['metrics'][0]['name']
 
@@ -218,7 +213,6 @@ class AlarmsFilterAction(tables.LinkAction):
     policy_rules = (("alarm", "alarm:filter"),)
     ajax = True
 
-
     def get_link_url(self):
         return urlresolvers.reverse(constants.URL_PREFIX + 'alarm_filter',
                                     args=())
